@@ -1,15 +1,14 @@
 <?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="fr" sourcelanguage="en">
+<!DOCTYPE TS><TS version="2.0" language="fr" sourcelanguage="en">
 <context>
     <name>HomeWorkCheckApp</name>
     <message>
-        <location filename="flo_check_homework/main.py" line="244"/>
+        <location filename="flo_check_homework/main.py" line="409"/>
         <source>Unable to obtain a location of type &lt;i&gt;CacheLocation&lt;/i&gt; with QtGui.QDesktopServices.storageLocation().</source>
         <translation>Impossible d&apos;obtenir un emplacement de type &lt;i&gt;CacheLocation&lt;/i&gt; via QtGui.QDesktopServices.storageLocation().</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="342"/>
+        <location filename="flo_check_homework/main.py" line="494"/>
         <source>{excMsg}
 
 Another instance of &apos;{prog}&apos; has acquired the lock file &apos;{lock}&apos;, but it is impossible to read that file in order to determine the PID of the other instance (for the reason indicated above). This can happen for instance if the lock file was removed by the other instance between the moment we tried to create it and the moment we tried to read it.
@@ -22,12 +21,12 @@ Une autre instance de &apos;{prog}&apos; a acquis le fichier verrou &apos;{lock}
 Remède : vérifiez que toutes les instances de &apos;{prog}&apos; sont fermées et effacez le fichier verrou s&apos;il existe encore.</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="388"/>
+        <location filename="flo_check_homework/main.py" line="540"/>
         <source>The configuration file &lt;i&gt;{0}&lt;/i&gt; was written in an old format. Please remove or rename this file before restarting &lt;i&gt;{1}&lt;/i&gt;.</source>
         <translation>Le fichier de configuration &lt;i&gt;{0}&lt;/i&gt; utilise un ancien format. Veuillez supprimer ou renommer ce fichier avant de relancer &lt;i&gt;{1}&lt;/i&gt;.</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="356"/>
+        <location filename="flo_check_homework/main.py" line="508"/>
         <source>&lt;p&gt;
 It seems there is already a running instance of &lt;i&gt;{prog}&lt;/i&gt; (PID {pid}). If this is not the case, please remove the lock file &lt;tt&gt;{lock}&lt;/tt&gt;.
 &lt;/p&gt;
@@ -41,6 +40,40 @@ Il semble qu&apos;il y ait déjà une instance de &lt;i&gt;{prog}&lt;/i&gt; en c
 &lt;p&gt;
 En raison du suivi des questions posées (par exemple, ne pas poser deux fois la même question au cours d&apos;une même session), il n&apos;est pas possible de lancer simultanément plusieurs instances de &lt;i&gt;{prog}&lt;/i&gt; sous le même compte utilisateur.&lt;/p&gt;</translation>
     </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="574"/>
+        <source>The following error was encountered when trying to execute the desired program:
+
+{excMsg}</source>
+        <translation>L&apos;erreur suivante a été rencontrée en essayant d&apos;exécuter le programme suivant :
+
+{excMsg}</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="600"/>
+        <source>The program &apos;{0}&apos; terminated abnormally (maybe killed by a signal).</source>
+        <translation>Le programme &apos;{0}&apos; s&apos;est terminé de manière anormale (peut-être tué par un signal).</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="616"/>
+        <source>The program &apos;{0}&apos; could not start; maybe the executable cannot be found or you don&apos;t have the required permissions.</source>
+        <translation>Le programme &apos;{0}&apos; n&apos;a pas pu démarrer ; peut-être que l&apos;exécutable est introuvable ou que vous n&apos;avez pas les permissions requises.</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="621"/>
+        <source>Unknown error while executing the program &apos;{0}&apos; (thanks to Qt for the precise diagnosis).</source>
+        <translation>Erreur inconnue lors de l&apos;exécution du programme &apos;{0}&apos; (merci à Qt pour la précision du diagnostic).</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="639"/>
+        <source>It is therefore impossible to find an eventual super magic token.</source>
+        <translation>Par conséquent, il est impossible de trouver un éventuel jeton super-magique.</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="658"/>
+        <source>Invalid syntax for the super magic token file:</source>
+        <translation>Syntaxe incorrecte pour le jeton super-magique :</translation>
+    </message>
 </context>
 <context>
     <name>ImageWindow</name>
@@ -53,32 +86,32 @@ En raison du suivi des questions posées (par exemple, ne pas poser deux fois la
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="flo_check_homework/main.py" line="1018"/>
+        <location filename="flo_check_homework/main.py" line="1298"/>
         <source>Password check</source>
         <translation>Vérification du mot de passe</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1043"/>
+        <location filename="flo_check_homework/main.py" line="1325"/>
         <source>&lt;i&gt;Division&lt;/i&gt; password:</source>
         <translation>Mot de passe &lt;i&gt;divisions&lt;/i&gt; :</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1050"/>
+        <location filename="flo_check_homework/main.py" line="1332"/>
         <source>&lt;i&gt;Multiplication&lt;/i&gt; password:</source>
         <translation>Mot de passe &lt;i&gt;multiplications&lt;/i&gt; :</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1056"/>
+        <location filename="flo_check_homework/main.py" line="1338"/>
         <source>&lt;i&gt;Addition&lt;/i&gt; password:</source>
         <translation>Mot de passe &lt;i&gt;additions&lt;/i&gt; :</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1066"/>
+        <location filename="flo_check_homework/main.py" line="1348"/>
         <source>&lt;i&gt;Substraction&lt;/i&gt; password:</source>
         <translation>Mot de passe &lt;i&gt;soustractions&lt;/i&gt; :</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1077"/>
+        <location filename="flo_check_homework/main.py" line="1359"/>
         <source>&amp;Calculus</source>
         <translation>&amp;Calcul</translation>
     </message>
@@ -88,127 +121,127 @@ En raison du suivi des questions posées (par exemple, ne pas poser deux fois la
         <translation type="obsolete">C&amp;onjugaison</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1114"/>
+        <location filename="flo_check_homework/main.py" line="1410"/>
         <source>Impossible to exit now.</source>
         <translation>Impossible de quitter maintenant.</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1115"/>
+        <location filename="flo_check_homework/main.py" line="1411"/>
         <source>I suggest you to examine the corrections before leaving.</source>
         <translation>Je vous suggère de réviser un peu avant de sortir.</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1178"/>
+        <location filename="flo_check_homework/main.py" line="1504"/>
         <source>About {0}</source>
         <translation>À propos de {0}</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1130"/>
+        <location filename="flo_check_homework/main.py" line="1428"/>
         <source>Little program that allows one to check and consolidate one&apos;s skills...</source>
         <translation>Petit programme permettant de vérifier et consolider les acquis avant de se détendre...</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1142"/>
+        <location filename="flo_check_homework/main.py" line="1440"/>
         <source>&amp;Test</source>
         <translation>&amp;Test</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1143"/>
+        <location filename="flo_check_homework/main.py" line="1444"/>
         <source>Ctrl+T</source>
         <translation>Ctrl+T</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1144"/>
+        <location filename="flo_check_homework/main.py" line="1445"/>
         <source>Test something</source>
         <translation>Tester quelque chose</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1147"/>
+        <location filename="flo_check_homework/main.py" line="1448"/>
         <source>&amp;Launch {0}</source>
         <translation>&amp;Lancer {0}</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1150"/>
+        <location filename="flo_check_homework/main.py" line="1453"/>
         <source>Ctrl+L</source>
         <translation>Ctrl+L</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1151"/>
+        <location filename="flo_check_homework/main.py" line="1454"/>
         <source>Launch the program {0}</source>
         <translation>Lancer le programme {0}</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1158"/>
+        <location filename="flo_check_homework/main.py" line="1462"/>
         <source>&amp;Magic word</source>
         <translation>&amp;Formule magique</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1162"/>
+        <location filename="flo_check_homework/main.py" line="1466"/>
         <source>Ctrl+M</source>
         <translation>Ctrl+F</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1163"/>
+        <location filename="flo_check_homework/main.py" line="1467"/>
         <source>Cast a spell</source>
         <translation>Jeter un sort</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1168"/>
+        <location filename="flo_check_homework/main.py" line="1494"/>
         <source>&amp;Quit</source>
         <translation>&amp;Quitter</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1171"/>
+        <location filename="flo_check_homework/main.py" line="1497"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1174"/>
+        <location filename="flo_check_homework/main.py" line="1500"/>
         <source>Quit the application</source>
         <translation>Quitter l&apos;application</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1180"/>
+        <location filename="flo_check_homework/main.py" line="1506"/>
         <source>Display information about the program</source>
         <translation>Affiche des informations sur le programme</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1185"/>
+        <location filename="flo_check_homework/main.py" line="1511"/>
         <source>&amp;File</source>
         <translation>&amp;Fichier</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1195"/>
+        <location filename="flo_check_homework/main.py" line="1525"/>
         <source>&amp;Help</source>
         <translation>&amp;Aide</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1199"/>
+        <location filename="flo_check_homework/main.py" line="1532"/>
         <source>File</source>
         <translation>Fichier</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1206"/>
+        <location filename="flo_check_homework/main.py" line="1549"/>
         <source>Ready</source>
         <translation>Prêt</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1269"/>
+        <location filename="flo_check_homework/main.py" line="1620"/>
         <source>Wrong password.</source>
         <translation>Mot de passe erroné.</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1270"/>
+        <location filename="flo_check_homework/main.py" line="1621"/>
         <source>You must try again and improve your score in order to be allowed to launch {0}!</source>
         <translation>Il faut recommencer et réaliser un meilleur score pour pouvoir lancer {0} !</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1280"/>
+        <location filename="flo_check_homework/main.py" line="1633"/>
         <source>Total score: </source>
         <translation>Score total : </translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1325"/>
+        <location filename="flo_check_homework/main.py" line="1856"/>
         <source>Magic word</source>
         <translation>Formule magique</translation>
     </message>
@@ -220,25 +253,25 @@ En raison du suivi des questions posées (par exemple, ne pas poser deux fois la
     <message>
         <location filename="flo_check_homework/main.py" line="1368"/>
         <source>The program &apos;{0}&apos; terminated abnormally (maybe killed by a signal).</source>
-        <translation>Le programme &apos;{0}&apos; s&apos;est terminé de manière anormale (peut-être tué par un signal).</translation>
+        <translation type="obsolete">Le programme &apos;{0}&apos; s&apos;est terminé de manière anormale (peut-être tué par un signal).</translation>
     </message>
     <message>
         <location filename="flo_check_homework/main.py" line="1384"/>
         <source>The program &apos;{0}&apos; could not start; maybe the executable cannot be found or you don&apos;t have the required permissions.</source>
-        <translation>Le programme &apos;{0}&apos; n&apos;a pas pu démarrer ; peut-être que l&apos;exécutable est introuvable ou que vous n&apos;avez pas les permissions requises.</translation>
+        <translation type="obsolete">Le programme &apos;{0}&apos; n&apos;a pas pu démarrer ; peut-être que l&apos;exécutable est introuvable ou que vous n&apos;avez pas les permissions requises.</translation>
     </message>
     <message>
         <location filename="flo_check_homework/main.py" line="1388"/>
         <source>Unknown error while executing the program &apos;{0}&apos; (thanks to Qt for the precise diagnosis).</source>
-        <translation>Erreur inconnue lors de l&apos;exécution du programme &apos;{0}&apos; (merci à Qt pour la précision du diagnostic).</translation>
+        <translation type="obsolete">Erreur inconnue lors de l&apos;exécution du programme &apos;{0}&apos; (merci à Qt pour la précision du diagnostic).</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1130"/>
+        <location filename="flo_check_homework/main.py" line="1428"/>
         <source>{progname} {progversion}</source>
         <translation>{progname} {progversion}</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1099"/>
+        <location filename="flo_check_homework/main.py" line="1381"/>
         <source>French C&amp;onjugation</source>
         <translation>C&amp;onjugaison</translation>
     </message>
@@ -248,50 +281,154 @@ En raison du suivi des questions posées (par exemple, ne pas poser deux fois la
         <translation type="obsolete">Trop de tentatives infructueuses pour la formule magique</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1325"/>
+        <location filename="flo_check_homework/main.py" line="1857"/>
         <source>I say {0} and {1}. Please enter the magic word.</source>
         <translation>Je dis {0} et {1}. Veuillez entrer la formule magique.</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1310"/>
+        <location filename="flo_check_homework/main.py" line="1858"/>
         <source>Too many failed attempts for the magic word.</source>
         <translation>Trop de tentatives infructueuses pour la formule magique.</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1312"/>
+        <location filename="flo_check_homework/main.py" line="1859"/>
         <source>After {0} failed attempts, the magic wand stops working.</source>
         <translation>Après {0} formules ratées, la baguette magique ne fonctionne plus.</translation>
     </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1473"/>
+        <source>&amp;Super magic word</source>
+        <translation>Formule &amp;super-magique</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1477"/>
+        <source>Ctrl+S</source>
+        <translation>Ctrl+S</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1478"/>
+        <source>Cast a super spell (with prolonged effects)</source>
+        <translation>Jeter un sort formidable (avec effets prolongés)</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1484"/>
+        <source>&amp;Remove the super magic token</source>
+        <translation>&amp;Retirer le jeton super-magique</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1488"/>
+        <source>Renounce the advantages given by the super magic token</source>
+        <translation>Renoncer aux avantages procurés par le jeton super-magique</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1518"/>
+        <source>&amp;Magic</source>
+        <translation>&amp;Magie</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1538"/>
+        <source>Magic</source>
+        <translation>Magie</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1841"/>
+        <source>Sorry, but you don&apos;t appear to be a wizard.</source>
+        <translation>Désolé, mais vous n&apos;avez pas l&apos;air d&apos;un magicien.</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1875"/>
+        <source>Super magic word</source>
+        <translation>Formule super-magique</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1876"/>
+        <source>I say {0} and {1}. Please enter the super magic word.</source>
+        <translation>Je dis {0} et {1}. Veuillez entrer la formule super-magique.</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1878"/>
+        <source>Too many failed attempts for the super magic word.</source>
+        <translation>Trop de tentatives infructueuses pour la formule super-magique.</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1880"/>
+        <source>After {0} failed attempts at the super magic word, the wand stops working.</source>
+        <translation>Après {0} formules super-magiques ratées, la baguette ne fonctionne plus.</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1673"/>
+        <source>It is therefore impossible to store the super magic token for future sessions.</source>
+        <translation>Par conséquent, il est impossible de stocker le jeton super-magique pour les sessions à venir.</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1699"/>
+        <source>You are now in possession of a super magic token that will be valid for about {avg} minutes (actually, between {min} and {max} minutes).</source>
+        <translation>Vous disposez désormais d&apos;un jeton super-magique valide pour une durée approximative de {avg} minutes (précisément : entre {min} et {max} minutes).</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1716"/>
+        <source>It is therefore impossible to find or remove any super magic token.</source>
+        <translation>Par conséquent, il est impossible de trouver ou retirer un jeton super-magique.</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1725"/>
+        <source>There is no super magic token to remove!</source>
+        <translation>Il n&apos;y a pas de jeton super-magique qui puisse être retiré !</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1740"/>
+        <source>Are you sure you want to remove the super magic token?</source>
+        <translation>Êtes-vous sûr de vouloir supprimer le jeton super-magique ?</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1764"/>
+        <source>The following error was encountered when trying to remove the super magic token:
+
+{excMsg}</source>
+        <translation>L&apos;erreur suivante a été rencontrée en essayant de retirer le jeton super-magique :
+
+{excMsg}</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1744"/>
+        <source>&amp;Remove</source>
+        <translation>&amp;Supprimer</translation>
+    </message>
+    <message>
+        <location filename="flo_check_homework/main.py" line="1395"/>
+        <source>You are not allowed to quit this program before {0} is terminated.</source>
+        <translation>Vous n&apos;êtes pas autorisé à quitter ce programme avant que {0} ne soit terminé.</translation>
+    </message>
 </context>
 <context>
     <name>MultipleInputQuestionLine</name>
     <message>
-        <location filename="flo_check_homework/main.py" line="529"/>
+        <location filename="flo_check_homework/main.py" line="817"/>
         <source> Ouch! </source>
         <translation> Aïe ! </translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="532"/>
+        <location filename="flo_check_homework/main.py" line="820"/>
         <source>Submit</source>
         <translation>Valider</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="552"/>
+        <location filename="flo_check_homework/main.py" line="840"/>
         <source>OK</source>
         <translation>OK</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="552"/>
+        <location filename="flo_check_homework/main.py" line="840"/>
         <source>Ouch!</source>
         <translation>Aïe !</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="565"/>
+        <location filename="flo_check_homework/main.py" line="853"/>
         <source>&lt;nothing&gt;</source>
         <translation>&lt;rien&gt;</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="566"/>
+        <location filename="flo_check_homework/main.py" line="854"/>
         <source>{0} (not {1})</source>
         <translation>{0} (pas {1})</translation>
     </message>
@@ -299,20 +436,20 @@ En raison du suivi des questions posées (par exemple, ne pas poser deux fois la
 <context>
     <name>Questionnaire</name>
     <message>
-        <location filename="flo_check_homework/main.py" line="818"/>
+        <location filename="flo_check_homework/main.py" line="1106"/>
         <source>Score: </source>
         <translation>Score : </translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="863"/>
+        <location filename="flo_check_homework/main.py" line="1151"/>
         <source>&amp;Submit all</source>
         <translation>&amp;Tout valider</translation>
     </message>
 </context>
-<context>
+<context encoding="UTF-8">
     <name>app</name>
     <message>
-        <location filename="flo_check_homework/main.py" line="797"/>
+        <location filename="flo_check_homework/main.py" line="1085"/>
         <source>{0}{1}/{2}</source>
         <translation>{0}{1}/{2}</translation>
     </message>
@@ -321,7 +458,7 @@ En raison du suivi des questions posées (par exemple, ne pas poser deux fois la
         <source>{0}: </source>
         <translation type="obsolete">{0} : </translation>
     </message>
-    <message utf8="true">
+    <message encoding="UTF-8">
         <location filename="flo_check_homework/exercise_generator.py" line="890"/>
         <source>{0} = </source>
         <translation>{0} = </translation>
@@ -331,12 +468,12 @@ En raison du suivi des questions posées (par exemple, ne pas poser deux fois la
         <source>E.D. of {0} by {1}</source>
         <translation>D.E. de {0} par {1}</translation>
     </message>
-    <message utf8="true">
+    <message encoding="UTF-8">
         <location filename="flo_check_homework/exercise_generator.py" line="941"/>
         <source>{0}: quotient = </source>
         <translation>{0} : quotient = </translation>
     </message>
-    <message utf8="true">
+    <message encoding="UTF-8">
         <location filename="flo_check_homework/exercise_generator.py" line="946"/>
         <source>; remainder = </source>
         <translation> ; reste = </translation>
@@ -351,12 +488,12 @@ Copyright (c) 2011-2013  Florent Rougon</source>
 Copyright (c) 2011-2013  Florent Rougon</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1514"/>
+        <location filename="flo_check_homework/main.py" line="303"/>
         <source>This is free software; see the source for copying conditions.  There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.</source>
         <translation>Ceci est un logiciel libre ; veuillez vous reporter à la distribution source pour les conditions dans lesquelles il peut être copié. Il n&apos;est couvert par AUCUNE GARANTIE, pas même de qualité marchande ou d&apos;adéquation à un besoin particulier.</translation>
     </message>
     <message>
-        <location filename="flo_check_homework/main.py" line="1511"/>
+        <location filename="flo_check_homework/main.py" line="300"/>
         <source>Written by Florent Rougon.
 
 Copyright (c) 2011-2014  Florent Rougon</source>
